@@ -1,11 +1,12 @@
 use std::fmt;
+use std::mem;
 
 use super::job_queue::JobState;
-use crate::util::{CargoResult, Dirty, Fresh, Freshness};
+use crate::util::CargoResult;
 
 pub struct Job {
-    dirty: Work,
-    fresh: Work,
+    work: Work,
+    fresh: Freshness,
 }
 
 /// Each proc should send its description before starting.
@@ -50,17 +51,26 @@ impl Work {
 
 impl Job {
     /// Creates a new job representing a unit of work.
-    pub fn new(dirty: Work, fresh: Work) -> Job {
-        Job { dirty, fresh }
+    pub fn new(work: Work, fresh: Freshness) -> Job {
+        Job { work, fresh }
     }
 
     /// Consumes this job by running it, returning the result of the
     /// computation.
-    pub fn run(self, fresh: Freshness, state: &JobState<'_>) -> CargoResult<()> {
-        match fresh {
-            Fresh => self.fresh.call(state),
-            Dirty => self.dirty.call(state),
-        }
+    pub fn run(self, state: &JobState<'_>) -> CargoResult<()> {
+        self.work.call(state)
+    }
+
+    /// Returns whether this job was fresh/dirty, where "fresh" means we're
+    /// likely to perform just some small bookkeeping where "dirty" means we'll
+    /// probably do something slow like invoke rustc.
+    pub fn freshness(&self) -> Freshness {
+        self.fresh
+    }
+
+    pub fn before(&mut self, next: Work) {
+        let prev = mem::replace(&mut self.work, Work::noop());
+        self.work = next.then(prev);
     }
 }
 
@@ -69,3 +79,13 @@ impl fmt::Debug for Job {
         write!(f, "Job {{ ... }}")
     }
 }
+
+/// Indication of the freshness of a package.
+///
+/// A fresh package does not necessarily need to be rebuilt (unless a dependency
+/// was also rebuilt), and a dirty package must always be rebuilt.
+#[derive(PartialEq, Eq, Debug, Clone, Copy)]
+pub enum Freshness {
+    Fresh,
+    Dirty,
+}
