@@ -10,7 +10,9 @@ pub use self::errors::{CargoTestError, CliError, ProcessError};
 pub use self::flock::{FileLock, Filesystem};
 pub use self::graph::Graph;
 pub use self::hex::{hash_u64, short_hash, to_hex};
-pub use self::lev_distance::lev_distance;
+pub use self::into_url::IntoUrl;
+pub use self::into_url_with_base::IntoUrlWithBase;
+pub use self::lev_distance::{closest, closest_msg, lev_distance};
 pub use self::lockserver::{LockServer, LockServerClient, LockServerStarted};
 pub use self::paths::{bytes2path, dylib_path, join_paths, path2bytes};
 pub use self::paths::{dylib_path_envvar, normalize_path};
@@ -20,8 +22,6 @@ pub use self::read2::read2;
 pub use self::rustc::Rustc;
 pub use self::sha256::Sha256;
 pub use self::to_semver::ToSemver;
-pub use self::to_url::ToUrl;
-pub use self::to_url_with_base::ToUrlWithBase;
 pub use self::vcs::{existing_vcs_repo, FossilRepo, GitRepo, HgRepo, PijulRepo};
 pub use self::workspace::{
     print_available_benches, print_available_binaries, print_available_examples,
@@ -38,6 +38,8 @@ mod flock;
 pub mod graph;
 pub mod hex;
 pub mod important_paths;
+pub mod into_url;
+mod into_url_with_base;
 pub mod job;
 pub mod lev_distance;
 mod lockserver;
@@ -51,8 +53,6 @@ mod read2;
 pub mod rustc;
 mod sha256;
 pub mod to_semver;
-pub mod to_url;
-mod to_url_with_base;
 pub mod toml;
 mod vcs;
 mod workspace;
