@@ -1,8 +1,8 @@
-use support::is_nightly;
-use support::paths::CargoPathExt;
-use support::{basic_bin_manifest, basic_lib_manifest, basic_manifest, project};
+use crate::support::is_nightly;
+use crate::support::paths::CargoPathExt;
+use crate::support::{basic_bin_manifest, basic_lib_manifest, basic_manifest, project};
 
-#[test]
+#[cargo_test]
 fn cargo_bench_simple() {
     if !is_nightly() {
         return;
@@ -29,7 +29,8 @@ fn cargo_bench_simple() {
             fn bench_hello(_b: &mut test::Bencher) {
                 assert_eq!(hello(), "hello")
             }"#,
-        ).build();
+        )
+        .build();
 
     p.cargo("build").run();
     assert!(p.bin("foo").is_file());
@@ -42,11 +43,12 @@ fn cargo_bench_simple() {
 [COMPILING] foo v0.5.0 ([CWD])
 [FINISHED] release [optimized] target(s) in [..]
 [RUNNING] target/release/deps/foo-[..][EXE]",
-        ).with_stdout_contains("test bench_hello ... bench: [..]")
+        )
+        .with_stdout_contains("test bench_hello ... bench: [..]")
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn bench_bench_implicit() {
     if !is_nightly() {
         return;
@@ -61,19 +63,22 @@ fn bench_bench_implicit() {
             extern crate test;
             #[bench] fn run1(_ben: &mut test::Bencher) { }
             fn main() { println!("Hello main!"); }"#,
-        ).file(
+        )
+        .file(
             "tests/other.rs",
             r#"
             #![feature(test)]
             extern crate test;
             #[bench] fn run3(_ben: &mut test::Bencher) { }"#,
-        ).file(
+        )
+        .file(
             "benches/mybench.rs",
             r#"
             #![feature(test)]
             extern crate test;
             #[bench] fn run2(_ben: &mut test::Bencher) { }"#,
-        ).build();
+        )
+        .build();
 
     p.cargo("bench --benches")
         .with_stderr(
@@ -83,11 +88,12 @@ fn bench_bench_implicit() {
 [RUNNING] target/release/deps/foo-[..][EXE]
 [RUNNING] target/release/deps/mybench-[..][EXE]
 ",
-        ).with_stdout_contains("test run2 ... bench: [..]")
+        )
+        .with_stdout_contains("test run2 ... bench: [..]")
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn bench_bin_implicit() {
     if !is_nightly() {
         return;
@@ -102,19 +108,22 @@ fn bench_bin_implicit() {
             extern crate test;
             #[bench] fn run1(_ben: &mut test::Bencher) { }
             fn main() { println!("Hello main!"); }"#,
-        ).file(
+        )
+        .file(
             "tests/other.rs",
             r#"
             #![feature(test)]
             extern crate test;
             #[bench] fn run3(_ben: &mut test::Bencher) { }"#,
-        ).file(
+        )
+        .file(
             "benches/mybench.rs",
             r#"
             #![feature(test)]
             extern crate test;
             #[bench] fn run2(_ben: &mut test::Bencher) { }"#,
-        ).build();
+        )
+        .build();
 
     p.cargo("bench --bins")
         .with_stderr(
@@ -123,11 +132,12 @@ fn bench_bin_implicit() {
 [FINISHED] release [optimized] target(s) in [..]
 [RUNNING] target/release/deps/foo-[..][EXE]
 ",
-        ).with_stdout_contains("test run1 ... bench: [..]")
+        )
+        .with_stdout_contains("test run1 ... bench: [..]")
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn bench_tarname() {
     if !is_nightly() {
         return;
@@ -140,13 +150,15 @@ fn bench_tarname() {
             #![feature(test)]
             extern crate test;
             #[bench] fn run1(_ben: &mut test::Bencher) { }"#,
-        ).file(
+        )
+        .file(
             "benches/bin2.rs",
             r#"
             #![feature(test)]
             extern crate test;
             #[bench] fn run2(_ben: &mut test::Bencher) { }"#,
-        ).build();
+        )
+        .build();
 
     p.cargo("bench --bench bin2")
         .with_stderr(
@@ -155,11 +167,12 @@ fn bench_tarname() {
 [FINISHED] release [optimized] target(s) in [..]
 [RUNNING] target/release/deps/bin2-[..][EXE]
 ",
-        ).with_stdout_contains("test run2 ... bench: [..]")
+        )
+        .with_stdout_contains("test run2 ... bench: [..]")
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn bench_multiple_targets() {
     if !is_nightly() {
         return;
@@ -172,19 +185,22 @@ fn bench_multiple_targets() {
             #![feature(test)]
             extern crate test;
             #[bench] fn run1(_ben: &mut test::Bencher) { }"#,
-        ).file(
+        )
+        .file(
             "benches/bin2.rs",
             r#"
             #![feature(test)]
             extern crate test;
             #[bench] fn run2(_ben: &mut test::Bencher) { }"#,
-        ).file(
+        )
+        .file(
             "benches/bin3.rs",
             r#"
             #![feature(test)]
             extern crate test;
             #[bench] fn run3(_ben: &mut test::Bencher) { }"#,
-        ).build();
+        )
+        .build();
 
     p.cargo("bench --bench bin1 --bench bin2")
         .with_stdout_contains("test run1 ... bench: [..]")
@@ -193,7 +209,7 @@ fn bench_multiple_targets() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn cargo_bench_verbose() {
     if !is_nightly() {
         return;
@@ -210,7 +226,8 @@ fn cargo_bench_verbose() {
             fn main() {}
             #[bench] fn bench_hello(_b: &mut test::Bencher) {}
         "#,
-        ).build();
+        )
+        .build();
 
     p.cargo("bench -v hello")
         .with_stderr(
@@ -219,11 +236,12 @@ fn cargo_bench_verbose() {
 [RUNNING] `rustc [..] src/main.rs [..]`
 [FINISHED] release [optimized] target(s) in [..]
 [RUNNING] `[..]target/release/deps/foo-[..][EXE] hello --bench`",
-        ).with_stdout_contains("test bench_hello ... bench: [..]")
+        )
+        .with_stdout_contains("test bench_hello ... bench: [..]")
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn many_similar_names() {
     if !is_nightly() {
         return;
@@ -239,7 +257,8 @@ fn many_similar_names() {
             pub fn foo() {}
             #[bench] fn lib_bench(_b: &mut test::Bencher) {}
         ",
-        ).file(
+        )
+        .file(
             "src/main.rs",
             "
             #![feature(test)]
@@ -250,7 +269,8 @@ fn many_similar_names() {
             fn main() {}
             #[bench] fn bin_bench(_b: &mut test::Bencher) { foo::foo() }
         ",
-        ).file(
+        )
+        .file(
             "benches/foo.rs",
             r#"
             #![feature(test)]
@@ -258,7 +278,8 @@ fn many_similar_names() {
             extern crate test;
             #[bench] fn bench_bench(_b: &mut test::Bencher) { foo::foo() }
         "#,
-        ).build();
+        )
+        .build();
 
     p.cargo("bench")
         .with_stdout_contains("test bin_bench ... bench:           0 ns/iter (+/- 0)")
@@ -267,7 +288,7 @@ fn many_similar_names() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn cargo_bench_failing_test() {
     if !is_nightly() {
         return;
@@ -293,7 +314,8 @@ fn cargo_bench_failing_test() {
             fn bench_hello(_b: &mut test::Bencher) {
                 assert_eq!(hello(), "nope")
             }"#,
-        ).build();
+        )
+        .build();
 
     p.cargo("build").run();
     assert!(p.bin("foo").is_file());
@@ -308,16 +330,18 @@ fn cargo_bench_failing_test() {
 [COMPILING] foo v0.5.0 ([CWD])[..]
 [FINISHED] release [optimized] target(s) in [..]
 [RUNNING] target/release/deps/foo-[..][EXE]",
-        ).with_either_contains(
+        )
+        .with_either_contains(
             "[..]thread '[..]' panicked at 'assertion failed: `(left == right)`[..]",
-        ).with_either_contains("[..]left: `\"hello\"`[..]")
+        )
+        .with_either_contains("[..]left: `\"hello\"`[..]")
         .with_either_contains("[..]right: `\"nope\"`[..]")
         .with_either_contains("[..]src/main.rs:15[..]")
         .with_status(101)
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn bench_with_lib_dep() {
     if !is_nightly() {
         return;
@@ -336,7 +360,8 @@ fn bench_with_lib_dep() {
             name = "baz"
             path = "src/main.rs"
         "#,
-        ).file(
+        )
+        .file(
             "src/lib.rs",
             r#"
             #![cfg_attr(test, feature(test))]
@@ -353,7 +378,8 @@ fn bench_with_lib_dep() {
             pub fn foo(){}
             #[bench] fn lib_bench(_b: &mut test::Bencher) {}
         "#,
-        ).file(
+        )
+        .file(
             "src/main.rs",
             "
             #![feature(test)]
@@ -367,7 +393,8 @@ fn bench_with_lib_dep() {
             #[bench]
             fn bin_bench(_b: &mut test::Bencher) {}
         ",
-        ).build();
+        )
+        .build();
 
     p.cargo("bench")
         .with_stderr(
@@ -376,12 +403,13 @@ fn bench_with_lib_dep() {
 [FINISHED] release [optimized] target(s) in [..]
 [RUNNING] target/release/deps/foo-[..][EXE]
 [RUNNING] target/release/deps/baz-[..][EXE]",
-        ).with_stdout_contains("test lib_bench ... bench: [..]")
+        )
+        .with_stdout_contains("test lib_bench ... bench: [..]")
         .with_stdout_contains("test bin_bench ... bench: [..]")
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn bench_with_deep_lib_dep() {
     if !is_nightly() {
         return;
@@ -400,7 +428,8 @@ fn bench_with_deep_lib_dep() {
             [dependencies.foo]
             path = "../foo"
         "#,
-        ).file(
+        )
+        .file(
             "src/lib.rs",
             "
             #![cfg_attr(test, feature(test))]
@@ -413,7 +442,8 @@ fn bench_with_deep_lib_dep() {
                 foo::foo();
             }
         ",
-        ).build();
+        )
+        .build();
     let _p2 = project()
         .file(
             "src/lib.rs",
@@ -427,7 +457,8 @@ fn bench_with_deep_lib_dep() {
             #[bench]
             fn foo_bench(_b: &mut test::Bencher) {}
         ",
-        ).build();
+        )
+        .build();
 
     p.cargo("bench")
         .with_stderr(
@@ -436,11 +467,12 @@ fn bench_with_deep_lib_dep() {
 [COMPILING] bar v0.0.1 ([CWD])
 [FINISHED] release [optimized] target(s) in [..]
 [RUNNING] target/release/deps/bar-[..][EXE]",
-        ).with_stdout_contains("test bar_bench ... bench: [..]")
+        )
+        .with_stdout_contains("test bar_bench ... bench: [..]")
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn external_bench_explicit() {
     if !is_nightly() {
         return;
@@ -459,7 +491,8 @@ fn external_bench_explicit() {
             name = "bench"
             path = "src/bench.rs"
         "#,
-        ).file(
+        )
+        .file(
             "src/lib.rs",
             r#"
             #![cfg_attr(test, feature(test))]
@@ -470,7 +503,8 @@ fn external_bench_explicit() {
             #[bench]
             fn internal_bench(_b: &mut test::Bencher) {}
         "#,
-        ).file(
+        )
+        .file(
             "src/bench.rs",
             r#"
             #![feature(test)]
@@ -481,7 +515,8 @@ fn external_bench_explicit() {
             #[bench]
             fn external_bench(_b: &mut test::Bencher) {}
         "#,
-        ).build();
+        )
+        .build();
 
     p.cargo("bench")
         .with_stderr(
@@ -490,12 +525,13 @@ fn external_bench_explicit() {
 [FINISHED] release [optimized] target(s) in [..]
 [RUNNING] target/release/deps/foo-[..][EXE]
 [RUNNING] target/release/deps/bench-[..][EXE]",
-        ).with_stdout_contains("test internal_bench ... bench: [..]")
+        )
+        .with_stdout_contains("test internal_bench ... bench: [..]")
         .with_stdout_contains("test external_bench ... bench: [..]")
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn external_bench_implicit() {
     if !is_nightly() {
         return;
@@ -514,7 +550,8 @@ fn external_bench_implicit() {
             #[bench]
             fn internal_bench(_b: &mut test::Bencher) {}
         "#,
-        ).file(
+        )
+        .file(
             "benches/external.rs",
             r#"
             #![feature(test)]
@@ -525,7 +562,8 @@ fn external_bench_implicit() {
             #[bench]
             fn external_bench(_b: &mut test::Bencher) {}
         "#,
-        ).build();
+        )
+        .build();
 
     p.cargo("bench")
         .with_stderr(
@@ -534,12 +572,13 @@ fn external_bench_implicit() {
 [FINISHED] release [optimized] target(s) in [..]
 [RUNNING] target/release/deps/foo-[..][EXE]
 [RUNNING] target/release/deps/external-[..][EXE]",
-        ).with_stdout_contains("test internal_bench ... bench: [..]")
+        )
+        .with_stdout_contains("test internal_bench ... bench: [..]")
         .with_stdout_contains("test external_bench ... bench: [..]")
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn bench_autodiscover_2015() {
     if !is_nightly() {
         return;
@@ -559,7 +598,8 @@ fn bench_autodiscover_2015() {
                 name = "bench_magic"
                 required-features = ["magic"]
             "#,
-        ).file("src/lib.rs", "")
+        )
+        .file("src/lib.rs", "")
         .file(
             "benches/bench_basic.rs",
             r#"
@@ -571,7 +611,8 @@ fn bench_autodiscover_2015() {
                 #[bench]
                 fn bench_basic(_b: &mut test::Bencher) {}
             "#,
-        ).file(
+        )
+        .file(
             "benches/bench_magic.rs",
             r#"
                 #![feature(test)]
@@ -582,7 +623,8 @@ fn bench_autodiscover_2015() {
                 #[bench]
                 fn bench_magic(_b: &mut test::Bencher) {}
             "#,
-        ).build();
+        )
+        .build();
 
     p.cargo("bench bench_basic")
         .with_stderr(
@@ -606,10 +648,11 @@ https://github.com/rust-lang/cargo/issues/5330
 [FINISHED] release [optimized] target(s) in [..]
 [RUNNING] target/release/deps/foo-[..][EXE]
 ",
-        ).run();
+        )
+        .run();
 }
 
-#[test]
+#[cargo_test]
 fn dont_run_examples() {
     if !is_nightly() {
         return;
@@ -620,11 +663,12 @@ fn dont_run_examples() {
         .file(
             "examples/dont-run-me-i-will-fail.rs",
             r#"fn main() { panic!("Examples should not be run by 'cargo test'"); }"#,
-        ).build();
+        )
+        .build();
     p.cargo("bench").run();
 }
 
-#[test]
+#[cargo_test]
 fn pass_through_command_line() {
     if !is_nightly() {
         return;
@@ -641,7 +685,8 @@ fn pass_through_command_line() {
             #[bench] fn foo(_b: &mut test::Bencher) {}
             #[bench] fn bar(_b: &mut test::Bencher) {}
         ",
-        ).build();
+        )
+        .build();
 
     p.cargo("bench bar")
         .with_stderr(
@@ -649,20 +694,22 @@ fn pass_through_command_line() {
 [COMPILING] foo v0.0.1 ([CWD])
 [FINISHED] release [optimized] target(s) in [..]
 [RUNNING] target/release/deps/foo-[..][EXE]",
-        ).with_stdout_contains("test bar ... bench: [..]")
+        )
+        .with_stdout_contains("test bar ... bench: [..]")
         .run();
 
     p.cargo("bench foo")
         .with_stderr(
             "[FINISHED] release [optimized] target(s) in [..]
 [RUNNING] target/release/deps/foo-[..][EXE]",
-        ).with_stdout_contains("test foo ... bench: [..]")
+        )
+        .with_stdout_contains("test foo ... bench: [..]")
         .run();
 }
 
 // Regression test for running cargo-bench twice with
 // tests in an rlib
-#[test]
+#[cargo_test]
 fn cargo_bench_twice() {
     if !is_nightly() {
         return;
@@ -681,14 +728,15 @@ fn cargo_bench_twice() {
             #[bench]
             fn dummy_bench(b: &mut test::Bencher) { }
             "#,
-        ).build();
+        )
+        .build();
 
     for _ in 0..2 {
         p.cargo("bench").run();
     }
 }
 
-#[test]
+#[cargo_test]
 fn lib_bin_same_name() {
     if !is_nightly() {
         return;
@@ -708,7 +756,8 @@ fn lib_bin_same_name() {
             [[bin]]
             name = "foo"
         "#,
-        ).file(
+        )
+        .file(
             "src/lib.rs",
             "
             #![cfg_attr(test, feature(test))]
@@ -716,7 +765,8 @@ fn lib_bin_same_name() {
             extern crate test;
             #[bench] fn lib_bench(_b: &mut test::Bencher) {}
         ",
-        ).file(
+        )
+        .file(
             "src/main.rs",
             "
             #![cfg_attr(test, feature(test))]
@@ -728,7 +778,8 @@ fn lib_bin_same_name() {
             #[bench]
             fn bin_bench(_b: &mut test::Bencher) {}
         ",
-        ).build();
+        )
+        .build();
 
     p.cargo("bench")
         .with_stderr(
@@ -737,11 +788,12 @@ fn lib_bin_same_name() {
 [FINISHED] release [optimized] target(s) in [..]
 [RUNNING] target/release/deps/foo-[..][EXE]
 [RUNNING] target/release/deps/foo-[..][EXE]",
-        ).with_stdout_contains_n("test [..] ... bench: [..]", 2)
+        )
+        .with_stdout_contains_n("test [..] ... bench: [..]", 2)
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn lib_with_standard_name() {
     if !is_nightly() {
         return;
@@ -764,7 +816,8 @@ fn lib_with_standard_name() {
             #[bench]
             fn foo_bench(_b: &mut test::Bencher) {}
         ",
-        ).file(
+        )
+        .file(
             "benches/bench.rs",
             "
             #![feature(test)]
@@ -774,7 +827,8 @@ fn lib_with_standard_name() {
             #[bench]
             fn bench(_b: &mut test::Bencher) { syntax::foo() }
         ",
-        ).build();
+        )
+        .build();
 
     p.cargo("bench")
         .with_stderr(
@@ -783,12 +837,13 @@ fn lib_with_standard_name() {
 [FINISHED] release [optimized] target(s) in [..]
 [RUNNING] target/release/deps/syntax-[..][EXE]
 [RUNNING] target/release/deps/bench-[..][EXE]",
-        ).with_stdout_contains("test foo_bench ... bench: [..]")
+        )
+        .with_stdout_contains("test foo_bench ... bench: [..]")
         .with_stdout_contains("test bench ... bench: [..]")
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn lib_with_standard_name2() {
     if !is_nightly() {
         return;
@@ -808,7 +863,8 @@ fn lib_with_standard_name2() {
             bench = false
             doctest = false
         "#,
-        ).file("src/lib.rs", "pub fn foo() {}")
+        )
+        .file("src/lib.rs", "pub fn foo() {}")
         .file(
             "src/main.rs",
             "
@@ -823,7 +879,8 @@ fn lib_with_standard_name2() {
             #[bench]
             fn bench(_b: &mut test::Bencher) { syntax::foo() }
         ",
-        ).build();
+        )
+        .build();
 
     p.cargo("bench")
         .with_stderr(
@@ -831,11 +888,12 @@ fn lib_with_standard_name2() {
 [COMPILING] syntax v0.0.1 ([CWD])
 [FINISHED] release [optimized] target(s) in [..]
 [RUNNING] target/release/deps/syntax-[..][EXE]",
-        ).with_stdout_contains("test bench ... bench: [..]")
+        )
+        .with_stdout_contains("test bench ... bench: [..]")
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn bench_dylib() {
     if !is_nightly() {
         return;
@@ -857,7 +915,8 @@ fn bench_dylib() {
             [dependencies.bar]
             path = "bar"
         "#,
-        ).file(
+        )
+        .file(
             "src/lib.rs",
             r#"
             #![cfg_attr(test, feature(test))]
@@ -870,7 +929,8 @@ fn bench_dylib() {
             #[bench]
             fn foo(_b: &mut test::Bencher) {}
         "#,
-        ).file(
+        )
+        .file(
             "benches/bench.rs",
             r#"
             #![feature(test)]
@@ -880,7 +940,8 @@ fn bench_dylib() {
             #[bench]
             fn foo(_b: &mut test::Bencher) { the_foo::bar(); }
         "#,
-        ).file(
+        )
+        .file(
             "bar/Cargo.toml",
             r#"
             [package]
@@ -892,7 +953,8 @@ fn bench_dylib() {
             name = "bar"
             crate_type = ["dylib"]
         "#,
-        ).file("bar/src/lib.rs", "pub fn baz() {}")
+        )
+        .file("bar/src/lib.rs", "pub fn baz() {}")
         .build();
 
     p.cargo("bench -v")
@@ -907,7 +969,8 @@ fn bench_dylib() {
 [FINISHED] release [optimized] target(s) in [..]
 [RUNNING] `[..]target/release/deps/foo-[..][EXE] --bench`
 [RUNNING] `[..]target/release/deps/bench-[..][EXE] --bench`",
-        ).with_stdout_contains_n("test foo ... bench: [..]", 2)
+        )
+        .with_stdout_contains_n("test foo ... bench: [..]", 2)
         .run();
 
     p.root().move_into_the_past();
@@ -919,11 +982,12 @@ fn bench_dylib() {
 [FINISHED] release [optimized] target(s) in [..]
 [RUNNING] `[..]target/release/deps/foo-[..][EXE] --bench`
 [RUNNING] `[..]target/release/deps/bench-[..][EXE] --bench`",
-        ).with_stdout_contains_n("test foo ... bench: [..]", 2)
+        )
+        .with_stdout_contains_n("test foo ... bench: [..]", 2)
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn bench_twice_with_build_cmd() {
     if !is_nightly() {
         return;
@@ -939,7 +1003,8 @@ fn bench_twice_with_build_cmd() {
             authors = []
             build = "build.rs"
         "#,
-        ).file("build.rs", "fn main() {}")
+        )
+        .file("build.rs", "fn main() {}")
         .file(
             "src/lib.rs",
             "
@@ -949,7 +1014,8 @@ fn bench_twice_with_build_cmd() {
             #[bench]
             fn foo(_b: &mut test::Bencher) {}
         ",
-        ).build();
+        )
+        .build();
 
     p.cargo("bench")
         .with_stderr(
@@ -957,18 +1023,20 @@ fn bench_twice_with_build_cmd() {
 [COMPILING] foo v0.0.1 ([CWD])
 [FINISHED] release [optimized] target(s) in [..]
 [RUNNING] target/release/deps/foo-[..][EXE]",
-        ).with_stdout_contains("test foo ... bench: [..]")
+        )
+        .with_stdout_contains("test foo ... bench: [..]")
         .run();
 
     p.cargo("bench")
         .with_stderr(
             "[FINISHED] release [optimized] target(s) in [..]
 [RUNNING] target/release/deps/foo-[..][EXE]",
-        ).with_stdout_contains("test foo ... bench: [..]")
+        )
+        .with_stdout_contains("test foo ... bench: [..]")
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn bench_with_examples() {
     if !is_nightly() {
         return;
@@ -989,7 +1057,8 @@ fn bench_with_examples() {
             [[bench]]
             name = "testb1"
         "#,
-        ).file(
+        )
+        .file(
             "src/lib.rs",
             r#"
             #![cfg_attr(test, feature(test))]
@@ -1009,7 +1078,8 @@ fn bench_with_examples() {
                 f2();
             }
         "#,
-        ).file(
+        )
+        .file(
             "benches/testb1.rs",
             "
             #![feature(test)]
@@ -1023,7 +1093,8 @@ fn bench_with_examples() {
                 foo::f2();
             }
         ",
-        ).file(
+        )
+        .file(
             "examples/teste1.rs",
             r#"
             extern crate foo;
@@ -1033,7 +1104,8 @@ fn bench_with_examples() {
                 foo::f1();
             }
         "#,
-        ).build();
+        )
+        .build();
 
     p.cargo("bench -v")
         .with_stderr(
@@ -1045,12 +1117,13 @@ fn bench_with_examples() {
 [FINISHED] release [optimized] target(s) in [..]
 [RUNNING] `[CWD]/target/release/deps/foo-[..][EXE] --bench`
 [RUNNING] `[CWD]/target/release/deps/testb1-[..][EXE] --bench`",
-        ).with_stdout_contains("test bench_bench1 ... bench: [..]")
+        )
+        .with_stdout_contains("test bench_bench1 ... bench: [..]")
         .with_stdout_contains("test bench_bench2 ... bench: [..]")
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn test_a_bench() {
     if !is_nightly() {
         return;
@@ -1074,7 +1147,8 @@ fn test_a_bench() {
             name = "b"
             test = true
         "#,
-        ).file("src/lib.rs", "")
+        )
+        .file("src/lib.rs", "")
         .file("benches/b.rs", "#[test] fn foo() {}")
         .build();
 
@@ -1084,11 +1158,12 @@ fn test_a_bench() {
 [COMPILING] foo v0.1.0 ([..])
 [FINISHED] dev [unoptimized + debuginfo] target(s) in [..]
 [RUNNING] target/debug/deps/b-[..][EXE]",
-        ).with_stdout_contains("test foo ... ok")
+        )
+        .with_stdout_contains("test foo ... ok")
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn test_bench_no_run() {
     if !is_nightly() {
         return;
@@ -1108,7 +1183,8 @@ fn test_bench_no_run() {
             #[bench]
             fn bench_baz(_: &mut Bencher) {}
         "#,
-        ).build();
+        )
+        .build();
 
     p.cargo("bench --no-run")
         .with_stderr(
@@ -1116,10 +1192,11 @@ fn test_bench_no_run() {
 [COMPILING] foo v0.0.1 ([..])
 [FINISHED] release [optimized] target(s) in [..]
 ",
-        ).run();
+        )
+        .run();
 }
 
-#[test]
+#[cargo_test]
 fn test_bench_no_fail_fast() {
     if !is_nightly() {
         return;
@@ -1150,7 +1227,8 @@ fn test_bench_no_fail_fast() {
             fn bench_nope(_b: &mut test::Bencher) {
                 assert_eq!("nope", hello())
             }"#,
-        ).build();
+        )
+        .build();
 
     p.cargo("bench --no-fail-fast -- --test-threads=1")
         .with_status(101)
@@ -1162,7 +1240,7 @@ fn test_bench_no_fail_fast() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn test_bench_multiple_packages() {
     if !is_nightly() {
         return;
@@ -1183,7 +1261,8 @@ fn test_bench_multiple_packages() {
             [dependencies.baz]
             path = "../baz"
         "#,
-        ).file("src/lib.rs", "")
+        )
+        .file("src/lib.rs", "")
         .build();
 
     let _bar = project()
@@ -1200,7 +1279,8 @@ fn test_bench_multiple_packages() {
             name = "bbar"
             test = true
         "#,
-        ).file("src/lib.rs", "")
+        )
+        .file("src/lib.rs", "")
         .file(
             "benches/bbar.rs",
             r#"
@@ -1212,7 +1292,8 @@ fn test_bench_multiple_packages() {
             #[bench]
             fn bench_bar(_b: &mut Bencher) {}
         "#,
-        ).build();
+        )
+        .build();
 
     let _baz = project()
         .at("baz")
@@ -1228,7 +1309,8 @@ fn test_bench_multiple_packages() {
             name = "bbaz"
             test = true
         "#,
-        ).file("src/lib.rs", "")
+        )
+        .file("src/lib.rs", "")
         .file(
             "benches/bbaz.rs",
             r#"
@@ -1240,7 +1322,8 @@ fn test_bench_multiple_packages() {
             #[bench]
             fn bench_baz(_b: &mut Bencher) {}
         "#,
-        ).build();
+        )
+        .build();
 
     p.cargo("bench -p bar -p baz")
         .with_stderr_contains("[RUNNING] target/release/deps/bbaz-[..][EXE]")
@@ -1250,7 +1333,7 @@ fn test_bench_multiple_packages() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn bench_all_workspace() {
     if !is_nightly() {
         return;
@@ -1269,7 +1352,8 @@ fn bench_all_workspace() {
 
             [workspace]
         "#,
-        ).file("src/main.rs", "fn main() {}")
+        )
+        .file("src/main.rs", "fn main() {}")
         .file(
             "benches/foo.rs",
             r#"
@@ -1281,7 +1365,8 @@ fn bench_all_workspace() {
             #[bench]
             fn bench_foo(_: &mut Bencher) -> () { () }
         "#,
-        ).file("bar/Cargo.toml", &basic_manifest("bar", "0.1.0"))
+        )
+        .file("bar/Cargo.toml", &basic_manifest("bar", "0.1.0"))
         .file("bar/src/lib.rs", "pub fn bar() {}")
         .file(
             "bar/benches/bar.rs",
@@ -1294,7 +1379,8 @@ fn bench_all_workspace() {
             #[bench]
             fn bench_bar(_: &mut Bencher) -> () { () }
         "#,
-        ).build();
+        )
+        .build();
 
     p.cargo("bench --all")
         .with_stderr_contains("[RUNNING] target/release/deps/bar-[..][EXE]")
@@ -1304,7 +1390,7 @@ fn bench_all_workspace() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn bench_all_exclude() {
     if !is_nightly() {
         return;
@@ -1321,7 +1407,8 @@ fn bench_all_exclude() {
             [workspace]
             members = ["bar", "baz"]
         "#,
-        ).file("src/main.rs", "fn main() {}")
+        )
+        .file("src/main.rs", "fn main() {}")
         .file("bar/Cargo.toml", &basic_manifest("bar", "0.1.0"))
         .file(
             "bar/src/lib.rs",
@@ -1335,21 +1422,24 @@ fn bench_all_exclude() {
                 b.iter(|| {});
             }
         "#,
-        ).file("baz/Cargo.toml", &basic_manifest("baz", "0.1.0"))
+        )
+        .file("baz/Cargo.toml", &basic_manifest("baz", "0.1.0"))
         .file(
             "baz/src/lib.rs",
             "#[test] pub fn baz() { break_the_build(); }",
-        ).build();
+        )
+        .build();
 
     p.cargo("bench --all --exclude baz")
         .with_stdout_contains(
             "\
 running 1 test
 test bar ... bench:           [..] ns/iter (+/- [..])",
-        ).run();
+        )
+        .run();
 }
 
-#[test]
+#[cargo_test]
 fn bench_all_virtual_manifest() {
     if !is_nightly() {
         return;
@@ -1362,7 +1452,8 @@ fn bench_all_virtual_manifest() {
             [workspace]
             members = ["bar", "baz"]
         "#,
-        ).file("bar/Cargo.toml", &basic_manifest("bar", "0.1.0"))
+        )
+        .file("bar/Cargo.toml", &basic_manifest("bar", "0.1.0"))
         .file("bar/src/lib.rs", "pub fn bar() {}")
         .file(
             "bar/benches/bar.rs",
@@ -1375,7 +1466,8 @@ fn bench_all_virtual_manifest() {
             #[bench]
             fn bench_bar(_: &mut Bencher) -> () { () }
         "#,
-        ).file("baz/Cargo.toml", &basic_manifest("baz", "0.1.0"))
+        )
+        .file("baz/Cargo.toml", &basic_manifest("baz", "0.1.0"))
         .file("baz/src/lib.rs", "pub fn baz() {}")
         .file(
             "baz/benches/baz.rs",
@@ -1388,7 +1480,8 @@ fn bench_all_virtual_manifest() {
             #[bench]
             fn bench_baz(_: &mut Bencher) -> () { () }
         "#,
-        ).build();
+        )
+        .build();
 
     // The order in which bar and baz are built is not guaranteed
     p.cargo("bench --all")
@@ -1400,7 +1493,7 @@ fn bench_all_virtual_manifest() {
 }
 
 // https://github.com/rust-lang/cargo/issues/4287
-#[test]
+#[cargo_test]
 fn legacy_bench_name() {
     if !is_nightly() {
         return;
@@ -1417,7 +1510,8 @@ fn legacy_bench_name() {
             [[bench]]
             name = "bench"
         "#,
-        ).file("src/lib.rs", "pub fn foo() {}")
+        )
+        .file("src/lib.rs", "pub fn foo() {}")
         .file(
             "src/bench.rs",
             r#"
@@ -1429,17 +1523,19 @@ fn legacy_bench_name() {
             #[bench]
             fn bench_foo(_: &mut Bencher) -> () { () }
         "#,
-        ).build();
+        )
+        .build();
 
     p.cargo("bench")
         .with_stderr_contains(
             "\
 [WARNING] path `[..]src/bench.rs` was erroneously implicitly accepted for benchmark `bench`,
 please set bench.path in Cargo.toml",
-        ).run();
+        )
+        .run();
 }
 
-#[test]
+#[cargo_test]
 fn bench_virtual_manifest_all_implied() {
     if !is_nightly() {
         return;
@@ -1452,7 +1548,8 @@ fn bench_virtual_manifest_all_implied() {
             [workspace]
             members = ["bar", "baz"]
         "#,
-        ).file("bar/Cargo.toml", &basic_manifest("bar", "0.1.0"))
+        )
+        .file("bar/Cargo.toml", &basic_manifest("bar", "0.1.0"))
         .file("bar/src/lib.rs", "pub fn foo() {}")
         .file(
             "bar/benches/bar.rs",
@@ -1463,7 +1560,8 @@ fn bench_virtual_manifest_all_implied() {
             #[bench]
             fn bench_bar(_: &mut Bencher) -> () { () }
         "#,
-        ).file("baz/Cargo.toml", &basic_manifest("baz", "0.1.0"))
+        )
+        .file("baz/Cargo.toml", &basic_manifest("baz", "0.1.0"))
         .file("baz/src/lib.rs", "pub fn baz() {}")
         .file(
             "baz/benches/baz.rs",
@@ -1474,7 +1572,8 @@ fn bench_virtual_manifest_all_implied() {
             #[bench]
             fn bench_baz(_: &mut Bencher) -> () { () }
         "#,
-        ).build();
+        )
+        .build();
 
     // The order in which bar and baz are built is not guaranteed
 
@@ -1485,3 +1584,49 @@ fn bench_virtual_manifest_all_implied() {
         .with_stdout_contains("test bench_bar ... bench: [..]")
         .run();
 }
+
+#[cargo_test]
+fn json_artifact_includes_executable_for_benchmark() {
+    if !is_nightly() {
+        return;
+    }
+
+    let p = project()
+        .file(
+            "benches/benchmark.rs",
+            r#"
+            #![feature(test)]
+            extern crate test;
+
+            use test::Bencher;
+
+            #[bench]
+            fn bench_foo(_: &mut Bencher) -> () { () }
+        "#,
+        )
+        .build();
+
+    p.cargo("bench --no-run --message-format=json")
+        .with_json(
+            r#"
+            {
+                "executable": "[..]/foo/target/release/benchmark-[..][EXE]",
+                "features": [],
+                "filenames": [ "[..]/foo/target/release/benchmark-[..][EXE]" ],
+                "fresh": false,
+                "package_id": "foo 0.0.1 ([..])",
+                "profile": "{...}",
+                "reason": "compiler-artifact",
+                "target": {
+                    "crate_types": [ "bin" ],
+                    "kind": [ "bench" ],
+                    "doctest": false,
+                    "edition": "2015",
+                    "name": "benchmark",
+                    "src_path": "[..]/foo/benches/benchmark.rs"
+                }
+            }
+        "#,
+        )
+        .run();
+}
