@@ -4,7 +4,7 @@ use std::io::prelude::*;
 use crate::support::registry::Package;
 use crate::support::{basic_manifest, paths, project, ProjectBuilder};
 
-#[test]
+#[cargo_test]
 fn adding_and_removing_packages() {
     let p = project()
         .file("src/main.rs", "fn main() {}")
@@ -64,7 +64,7 @@ fn adding_and_removing_packages() {
     assert_eq!(lock1, lock4);
 }
 
-#[test]
+#[cargo_test]
 fn no_index_update() {
     Package::new("serde", "1.0.0").publish();
 
@@ -95,7 +95,7 @@ fn no_index_update() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn preserve_metadata() {
     let p = project()
         .file("src/main.rs", "fn main() {}")
@@ -129,7 +129,7 @@ foo = "bar"
     assert!(lock.contains(metadata.trim()), "{}", lock);
 }
 
-#[test]
+#[cargo_test]
 fn preserve_line_endings_issue_2076() {
     let p = project()
         .file("src/main.rs", "fn main() {}")
@@ -144,7 +144,7 @@ fn preserve_line_endings_issue_2076() {
 
     let lock0 = p.read_lockfile();
 
-    assert!(lock0.starts_with("[[package]]\n"));
+    assert!(lock0.starts_with("# This file is automatically @generated by Cargo.\n# It is not intended for manual editing.\n"));
 
     let lock1 = lock0.replace("\n", "\r\n");
     {
@@ -158,11 +158,11 @@ fn preserve_line_endings_issue_2076() {
 
     let lock2 = p.read_lockfile();
 
-    assert!(lock2.starts_with("[[package]]\r\n"));
+    assert!(lock2.starts_with("# This file is automatically @generated by Cargo.\r\n# It is not intended for manual editing.\r\n"));
     assert_eq!(lock1, lock2);
 }
 
-#[test]
+#[cargo_test]
 fn cargo_update_generate_lockfile() {
     let p = project().file("src/main.rs", "fn main() {}").build();
 
@@ -178,7 +178,7 @@ fn cargo_update_generate_lockfile() {
     assert!(lockfile.is_file());
 }
 
-#[test]
+#[cargo_test]
 fn duplicate_entries_in_lockfile() {
     let _a = ProjectBuilder::new(paths::root().join("a"))
         .file(
@@ -225,7 +225,7 @@ fn duplicate_entries_in_lockfile() {
         .file("src/lib.rs", "")
         .build();
 
-    // should fail due to a duplicate package `common` in the lockfile
+    // should fail due to a duplicate package `common` in the lock file
     b.cargo("build")
         .with_status(101)
         .with_stderr_contains(
