@@ -21,7 +21,7 @@ fn pkg(name: &str, vers: &str) {
         .publish();
 }
 
-#[test]
+#[cargo_test]
 fn simple() {
     pkg("foo", "0.0.1");
 
@@ -48,7 +48,7 @@ fn simple() {
     assert_has_not_installed_exe(cargo_home(), "foo");
 }
 
-#[test]
+#[cargo_test]
 fn multiple_pkgs() {
     pkg("foo", "0.0.1");
     pkg("bar", "0.0.2");
@@ -96,7 +96,7 @@ fn multiple_pkgs() {
     assert_has_not_installed_exe(cargo_home(), "bar");
 }
 
-#[test]
+#[cargo_test]
 fn pick_max_version() {
     pkg("foo", "0.1.0");
     pkg("foo", "0.2.0");
@@ -122,7 +122,7 @@ fn pick_max_version() {
     assert_has_installed_exe(cargo_home(), "foo");
 }
 
-#[test]
+#[cargo_test]
 fn installs_beta_version_by_explicit_name_from_git() {
     let p = git::repo(&paths::root().join("foo"))
         .file("Cargo.toml", &basic_manifest("foo", "0.3.0-beta.1"))
@@ -136,7 +136,7 @@ fn installs_beta_version_by_explicit_name_from_git() {
     assert_has_installed_exe(cargo_home(), "foo");
 }
 
-#[test]
+#[cargo_test]
 fn missing() {
     pkg("foo", "0.0.1");
     cargo_process("install bar")
@@ -150,7 +150,7 @@ fn missing() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn bad_version() {
     pkg("foo", "0.0.1");
     cargo_process("install foo --vers=0.2.0")
@@ -164,7 +164,7 @@ fn bad_version() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn bad_paths() {
     cargo_process("install")
         .with_status(101)
@@ -189,7 +189,7 @@ fn bad_paths() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn install_location_precedence() {
     pkg("foo", "0.0.1");
 
@@ -245,7 +245,7 @@ fn install_location_precedence() {
     assert_has_installed_exe(&t4, "foo");
 }
 
-#[test]
+#[cargo_test]
 fn install_path() {
     let p = project().file("src/main.rs", "fn main() {}").build();
 
@@ -262,7 +262,7 @@ Add --force to overwrite
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn multiple_crates_error() {
     let p = git::repo(&paths::root().join("foo"))
         .file("Cargo.toml", &basic_manifest("foo", "0.1.0"))
@@ -283,7 +283,7 @@ fn multiple_crates_error() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn multiple_crates_select() {
     let p = git::repo(&paths::root().join("foo"))
         .file("Cargo.toml", &basic_manifest("foo", "0.1.0"))
@@ -306,7 +306,7 @@ fn multiple_crates_select() {
     assert_has_installed_exe(cargo_home(), "bar");
 }
 
-#[test]
+#[cargo_test]
 fn multiple_crates_git_all() {
     let p = git::repo(&paths::root().join("foo"))
         .file(
@@ -331,7 +331,7 @@ members = ["bin1", "bin2"]
     cargo_process(&format!("install --git {} bin1 bin2", p.url().to_string())).run();
 }
 
-#[test]
+#[cargo_test]
 fn multiple_crates_auto_binaries() {
     let p = project()
         .file(
@@ -355,7 +355,7 @@ fn multiple_crates_auto_binaries() {
     assert_has_installed_exe(cargo_home(), "foo");
 }
 
-#[test]
+#[cargo_test]
 fn multiple_crates_auto_examples() {
     let p = project()
         .file(
@@ -390,7 +390,7 @@ fn multiple_crates_auto_examples() {
     assert_has_installed_exe(cargo_home(), "foo");
 }
 
-#[test]
+#[cargo_test]
 fn no_binaries_or_examples() {
     let p = project()
         .file(
@@ -417,7 +417,7 @@ fn no_binaries_or_examples() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn no_binaries() {
     let p = project()
         .file("src/lib.rs", "")
@@ -436,7 +436,7 @@ fn no_binaries() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn examples() {
     let p = project()
         .file("src/lib.rs", "")
@@ -450,7 +450,7 @@ fn examples() {
     assert_has_installed_exe(cargo_home(), "foo");
 }
 
-#[test]
+#[cargo_test]
 fn install_twice() {
     let p = project()
         .file("src/bin/foo-bin1.rs", "fn main() {}")
@@ -471,7 +471,7 @@ Add --force to overwrite
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn install_force() {
     let p = project().file("src/main.rs", "fn main() {}").build();
 
@@ -507,7 +507,7 @@ foo v0.2.0 ([..]):
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn install_force_partial_overlap() {
     let p = project()
         .file("src/bin/foo-bin1.rs", "fn main() {}")
@@ -552,7 +552,7 @@ foo v0.2.0 ([..]):
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn install_force_bin() {
     let p = project()
         .file("src/bin/foo-bin1.rs", "fn main() {}")
@@ -594,7 +594,7 @@ foo v0.2.0 ([..]):
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn compile_failure() {
     let p = project().file("src/main.rs", "").build();
 
@@ -615,7 +615,7 @@ To learn more, run the command again with --verbose.
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn git_repo() {
     let p = git::repo(&paths::root().join("foo"))
         .file("Cargo.toml", &basic_manifest("foo", "0.1.0"))
@@ -641,7 +641,7 @@ fn git_repo() {
     assert_has_installed_exe(cargo_home(), "foo");
 }
 
-#[test]
+#[cargo_test]
 fn list() {
     pkg("foo", "0.0.1");
     pkg("bar", "0.2.1");
@@ -663,7 +663,7 @@ foo v0.0.1:
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn list_error() {
     pkg("foo", "0.0.1");
     cargo_process("install foo").run();
@@ -699,7 +699,7 @@ Caused by:
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn uninstall_pkg_does_not_exist() {
     cargo_process("uninstall foo")
         .with_status(101)
@@ -707,7 +707,7 @@ fn uninstall_pkg_does_not_exist() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn uninstall_bin_does_not_exist() {
     pkg("foo", "0.0.1");
 
@@ -718,7 +718,7 @@ fn uninstall_bin_does_not_exist() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn uninstall_piecemeal() {
     let p = project()
         .file("src/bin/foo.rs", "fn main() {}")
@@ -747,7 +747,7 @@ fn uninstall_piecemeal() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn subcommand_works_out_of_the_box() {
     Package::new("cargo-foo", "1.0.0")
         .file("src/main.rs", r#"fn main() { println!("bar"); }"#)
@@ -759,7 +759,7 @@ fn subcommand_works_out_of_the_box() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn installs_from_cwd_by_default() {
     let p = project().file("src/main.rs", "fn main() {}").build();
 
@@ -774,7 +774,7 @@ fn installs_from_cwd_by_default() {
     assert_has_installed_exe(cargo_home(), "foo");
 }
 
-#[test]
+#[cargo_test]
 fn installs_from_cwd_with_2018_warnings() {
     let p = project()
         .file(
@@ -802,7 +802,7 @@ fn installs_from_cwd_with_2018_warnings() {
     assert_has_not_installed_exe(cargo_home(), "foo");
 }
 
-#[test]
+#[cargo_test]
 fn uninstall_cwd() {
     let p = project().file("src/main.rs", "fn main() {}").build();
     p.cargo("install --path .")
@@ -830,7 +830,7 @@ fn uninstall_cwd() {
     assert_has_not_installed_exe(cargo_home(), "foo");
 }
 
-#[test]
+#[cargo_test]
 fn uninstall_cwd_not_installed() {
     let p = project().file("src/main.rs", "fn main() {}").build();
     p.cargo("uninstall")
@@ -843,7 +843,7 @@ fn uninstall_cwd_not_installed() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn uninstall_cwd_no_project() {
     let err_msg = if cfg!(windows) {
         "The system cannot find the file specified."
@@ -864,7 +864,7 @@ Caused by:
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn do_not_rebuilds_on_local_install() {
     let p = project().file("src/main.rs", "fn main() {}").build();
 
@@ -887,7 +887,7 @@ fn do_not_rebuilds_on_local_install() {
     assert_has_installed_exe(cargo_home(), "foo");
 }
 
-#[test]
+#[cargo_test]
 fn reports_unsuccessful_subcommand_result() {
     Package::new("cargo-fail", "1.0.0")
         .file("src/main.rs", "fn main() { panic!(); }")
@@ -902,7 +902,7 @@ fn reports_unsuccessful_subcommand_result() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn git_with_lockfile() {
     let p = git::repo(&paths::root().join("foo"))
         .file(
@@ -940,7 +940,7 @@ fn git_with_lockfile() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn q_silences_warnings() {
     let p = project().file("src/main.rs", "fn main() {}").build();
 
@@ -950,7 +950,7 @@ fn q_silences_warnings() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn readonly_dir() {
     pkg("foo", "0.0.1");
 
@@ -965,7 +965,7 @@ fn readonly_dir() {
     assert_has_installed_exe(cargo_home(), "foo");
 }
 
-#[test]
+#[cargo_test]
 fn use_path_workspace() {
     Package::new("foo", "1.0.0").publish();
     let p = project()
@@ -1004,7 +1004,7 @@ fn use_path_workspace() {
     assert_eq!(lock, lock2, "different lockfiles");
 }
 
-#[test]
+#[cargo_test]
 fn dev_dependencies_no_check() {
     Package::new("foo", "1.0.0").publish();
     let p = project()
@@ -1030,7 +1030,7 @@ fn dev_dependencies_no_check() {
     p.cargo("install").run();
 }
 
-#[test]
+#[cargo_test]
 fn dev_dependencies_lock_file_untouched() {
     Package::new("foo", "1.0.0").publish();
     let p = project()
@@ -1058,7 +1058,7 @@ fn dev_dependencies_lock_file_untouched() {
     assert!(lock == lock2, "different lockfiles");
 }
 
-#[test]
+#[cargo_test]
 fn install_target_native() {
     pkg("foo", "0.1.0");
 
@@ -1068,7 +1068,7 @@ fn install_target_native() {
     assert_has_installed_exe(cargo_home(), "foo");
 }
 
-#[test]
+#[cargo_test]
 fn install_target_foreign() {
     if cross_compile::disabled() {
         return;
@@ -1082,7 +1082,7 @@ fn install_target_foreign() {
     assert_has_installed_exe(cargo_home(), "foo");
 }
 
-#[test]
+#[cargo_test]
 fn vers_precise() {
     pkg("foo", "0.1.1");
     pkg("foo", "0.1.2");
@@ -1092,7 +1092,7 @@ fn vers_precise() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn version_too() {
     pkg("foo", "0.1.1");
     pkg("foo", "0.1.2");
@@ -1102,7 +1102,7 @@ fn version_too() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn not_both_vers_and_version() {
     pkg("foo", "0.1.1");
     pkg("foo", "0.1.2");
@@ -1118,7 +1118,7 @@ but cannot be used multiple times
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn legacy_version_requirement() {
     pkg("foo", "0.1.1");
 
@@ -1134,17 +1134,17 @@ and will continue to do so, but this behavior will be removed eventually
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn test_install_git_cannot_be_a_base_url() {
     cargo_process("install --git github.com:rust-lang-nursery/rustfmt.git").with_status(101).with_stderr("error: invalid url `github.com:rust-lang-nursery/rustfmt.git`: cannot-be-a-base-URLs are not supported").run();
 }
 
-#[test]
+#[cargo_test]
 fn uninstall_multiple_and_specifying_bin() {
     cargo_process("uninstall foo bar --bin baz").with_status(101).with_stderr("error: A binary can only be associated with a single installed package, specifying multiple specs with --bin is redundant.").run();
 }
 
-#[test]
+#[cargo_test]
 fn uninstall_multiple_and_some_pkg_does_not_exist() {
     pkg("foo", "0.0.1");
 
@@ -1166,7 +1166,7 @@ error: some packages failed to uninstall
     assert_has_not_installed_exe(cargo_home(), "bar");
 }
 
-#[test]
+#[cargo_test]
 fn custom_target_dir_for_git_source() {
     let p = git::repo(&paths::root().join("foo"))
         .file("Cargo.toml", &basic_manifest("foo", "0.1.0"))
@@ -1185,7 +1185,7 @@ fn custom_target_dir_for_git_source() {
     assert!(paths::root().join("target/release").is_dir());
 }
 
-#[test]
+#[cargo_test]
 fn install_respects_lock_file() {
     // `cargo install` now requires --locked to use a Cargo.lock.
     Package::new("bar", "0.1.0").publish();
@@ -1224,7 +1224,7 @@ dependencies = [
     cargo_process("install --locked foo").run();
 }
 
-#[test]
+#[cargo_test]
 fn install_path_respects_lock_file() {
     // --path version of install_path_respects_lock_file, --locked is required
     // to use Cargo.lock.
@@ -1270,7 +1270,7 @@ dependencies = [
     p.cargo("install --path . --locked").run();
 }
 
-#[test]
+#[cargo_test]
 fn lock_file_path_deps_ok() {
     Package::new("bar", "0.1.0").publish();
 
@@ -1301,7 +1301,7 @@ dependencies = [
     cargo_process("install foo").run();
 }
 
-#[test]
+#[cargo_test]
 fn install_empty_argument() {
     // Bug 5229
     cargo_process("install")
@@ -1313,7 +1313,7 @@ fn install_empty_argument() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn git_repo_replace() {
     let p = git::repo(&paths::root().join("foo"))
         .file("Cargo.toml", &basic_manifest("foo", "0.1.0"))
@@ -1341,7 +1341,7 @@ fn git_repo_replace() {
         .contains(&format!("{}", new_rev)));
 }
 
-#[test]
+#[cargo_test]
 fn workspace_uses_workspace_target_dir() {
     let p = project()
         .file(
@@ -1377,7 +1377,7 @@ fn workspace_uses_workspace_target_dir() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn install_ignores_local_cargo_config() {
     pkg("bar", "0.0.1");
 
@@ -1396,7 +1396,7 @@ fn install_ignores_local_cargo_config() {
     assert_has_installed_exe(cargo_home(), "bar");
 }
 
-#[test]
+#[cargo_test]
 fn install_global_cargo_config() {
     pkg("bar", "0.0.1");
 
@@ -1417,7 +1417,7 @@ fn install_global_cargo_config() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn install_path_config() {
     project()
         .file(
@@ -1435,7 +1435,7 @@ fn install_path_config() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn install_version_req() {
     // Try using a few versionreq styles.
     pkg("foo", "0.0.3");
