@@ -1,4 +1,4 @@
-use support::{basic_bin_manifest, main_file, project};
+use crate::support::{basic_bin_manifest, main_file, project};
 
 static MANIFEST_OUTPUT: &'static str = r#"
 {
@@ -14,6 +14,7 @@ static MANIFEST_OUTPUT: &'static str = r#"
     "keywords": [],
     "license": null,
     "license_file": null,
+    "links": null,
     "description": null,
     "edition": "2015",
     "source":null,
@@ -21,6 +22,7 @@ static MANIFEST_OUTPUT: &'static str = r#"
     "targets":[{
         "kind":["bin"],
         "crate_types":["bin"],
+        "doctest": false,
         "edition": "2015",
         "name":"foo",
         "src_path":"[..]/foo/src/foo.rs"
@@ -30,7 +32,7 @@ static MANIFEST_OUTPUT: &'static str = r#"
     "metadata": null
 }"#;
 
-#[test]
+#[cargo_test]
 fn cargo_read_manifest_path_to_cargo_toml_relative() {
     let p = project()
         .file("Cargo.toml", &basic_bin_manifest("foo"))
@@ -43,7 +45,7 @@ fn cargo_read_manifest_path_to_cargo_toml_relative() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn cargo_read_manifest_path_to_cargo_toml_absolute() {
     let p = project()
         .file("Cargo.toml", &basic_bin_manifest("foo"))
@@ -57,7 +59,7 @@ fn cargo_read_manifest_path_to_cargo_toml_absolute() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 fn cargo_read_manifest_path_to_cargo_toml_parent_relative() {
     let p = project()
         .file("Cargo.toml", &basic_bin_manifest("foo"))
@@ -70,10 +72,11 @@ fn cargo_read_manifest_path_to_cargo_toml_parent_relative() {
         .with_stderr(
             "[ERROR] the manifest-path must be \
              a path to a Cargo.toml file",
-        ).run();
+        )
+        .run();
 }
 
-#[test]
+#[cargo_test]
 fn cargo_read_manifest_path_to_cargo_toml_parent_absolute() {
     let p = project()
         .file("Cargo.toml", &basic_bin_manifest("foo"))
@@ -87,17 +90,16 @@ fn cargo_read_manifest_path_to_cargo_toml_parent_absolute() {
         .with_stderr(
             "[ERROR] the manifest-path must be \
              a path to a Cargo.toml file",
-        ).run();
+        )
+        .run();
 }
 
-#[test]
+#[cargo_test]
 fn cargo_read_manifest_cwd() {
     let p = project()
         .file("Cargo.toml", &basic_bin_manifest("foo"))
         .file("src/foo.rs", &main_file(r#""i am foo""#, &[]))
         .build();
 
-    p.cargo("read-manifest")
-        .with_json(MANIFEST_OUTPUT)
-        .run();
+    p.cargo("read-manifest").with_json(MANIFEST_OUTPUT).run();
 }
