@@ -1,7 +1,7 @@
+use crate::support::project;
 use cargo;
-use support::project;
 
-#[test]
+#[cargo_test]
 fn simple() {
     let p = project().build();
 
@@ -14,20 +14,20 @@ fn simple() {
         .run();
 }
 
-#[test]
+#[cargo_test]
 #[cfg_attr(target_os = "windows", ignore)]
 fn version_works_without_rustc() {
     let p = project().build();
     p.cargo("version").env("PATH", "").run();
 }
 
-#[test]
+#[cargo_test]
 fn version_works_with_bad_config() {
     let p = project().file(".cargo/config", "this is not toml").build();
     p.cargo("version").run();
 }
 
-#[test]
+#[cargo_test]
 fn version_works_with_bad_target_dir() {
     let p = project()
         .file(
@@ -36,6 +36,7 @@ fn version_works_with_bad_target_dir() {
             [build]
             target-dir = 4
         "#,
-        ).build();
+        )
+        .build();
     p.cargo("version").run();
 }
